@@ -49,7 +49,7 @@
 #'   coefficient = c(0.05))
 #' model <- createGlmModel(coefficients, intercept = -2.5)
 #' data("simulationProfile")
-#' plpData <- simulatePlpData(simulationProfile, n=50)
+#' plpData <- simulatePlpData(simulationProfile, n = 50, seed = 42)
 #' prediction <- predictPlp(model, plpData, plpData$cohorts)
 #' # see the predicted risk values
 #' prediction$value
@@ -90,7 +90,13 @@ createGlmModel <- function(
     mapping = mapping,
     predictionFunction = "PatientLevelPrediction::predictGlm"
   )
-  existingModel <- list(model = "existingGlm")
+  # add param with modelType attribute 
+  param <- list()
+  attr(param, "settings") <- list(modelType = 'GLM')
+  existingModel <- list(
+    model = "existingGlm",
+    param = param
+  )
   class(existingModel) <- "modelSettings"
 
   plpModel <- list(
@@ -153,7 +159,7 @@ createGlmModel <- function(
 #'   coefficient = c(0.05))
 #' model <- createGlmModel(coefficients, intercept = -2.5)
 #' data("simulationProfile")
-#' plpData <- simulatePlpData(simulationProfile, n=50)
+#' plpData <- simulatePlpData(simulationProfile, n = 50, seed = 42)
 #' prediction <- predictGlm(model, plpData, plpData$cohorts)
 #' # see the predicted risk values
 #' head(prediction)
